# Please keep this package in sync with FC

%define oname		osinfo

%define api		1.0
%define major		0
%define libname		%mklibname %{oname} %{api} %{major}
%define develname	%mklibname %{oname} %{api} -d

%define girmajor	1.0
%define girname		%mklibname %{oname}-gir %{girmajor}

%global __provides_exclude_from ^%{_datadir}/doc/%{develname}/demo.*$
%global __requires_exclude_from ^%{_datadir}/doc/%{develname}/demo.*$

Summary:	A library for managing OS information for virtualization
Name:		libosinfo
Version:	1.8.0
Release:	%mkrel 2
License:	LGPLv2+
Group:		System/Libraries
Source:		https://releases.pagure.io/%{name}/%{name}-%{version}.tar.xz
URL:		https://libosinfo.org/

###Patches###

BuildRequires:	meson
BuildRequires:	gcc
BuildRequires:	git
BuildRequires:	gtk-doc
BuildRequires:	ldetect-lst
BuildRequires:	gettext-devel
BuildRequires:	glib2-devel
BuildRequires:	pkgconfig(libxml-2.0) >= 2.6.0
BuildRequires:	libsoup-devel
BuildRequires:	vala
BuildRequires:	vala-tools
BuildRequires:	pkgconfig(gobject-introspection-1.0)
BuildRequires:	pkgconfig(libxslt)
# tests require xmllint:
BuildRequires:	libxml2-utils
BuildRequires:	osinfo-db
Requires: osinfo-db
Requires: osinfo-db-tools

%description
libosinfo is a library that allows virtualization provisioning tools to
determine the optimal device settings for a hypervisor/operating system
combination.

%package -n %{libname}
Summary:	Library plugin handling
Group:		System/Libraries
Requires:	%{name} = %{version}-%{release}
Provides:	%{mklibname %{oname} %{major}} = %{version}-%{release}

%description -n %{libname}
libosinfo is a library that allows virtualization provisioning tools to
determine the optimal device settings for a hypervisor/operating system
combination.

%package -n %{develname}
Summary:	Development files for %{name}
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Requires:	%{girname} = %{version}-%{release}
Provides:	%{name}-devel = %version-%release
Provides:	%{oname}-devel = %{version}-%{release}

%description -n %{develname}
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

Libraries, includes, etc. to compile with the libosinfo library

%package vala
Summary:	Vala bindings
Group:		Development/Other
Requires:	%{name} = %{version}-%{release}

%description vala
libosinfo is a library that allows virtualization provisioning tools to
determine the optimal device settings for a hypervisor/operating system
combination.

This package provides the Vala bindings for libosinfo library.
 
%package -n %{girname}
Summary:	GObject Introspection interface description for %{name}
Group:		System/Libraries
Requires:	%{libname} = %{version}-%{release}

%description -n %{girname}
GObject Introspection interface description for %{name}.

%prep
%autosetup -S git

%build
%meson \
    -Denable-gtk-doc=true \
    -Denable-tests=true \
    -Denable-introspection=enabled \
    -Denable-vala=enabled
%meson_build

%install
%meson_install

%find_lang %{name}

%check
%meson_test

%files -f %{name}.lang
%doc AUTHORS ChangeLog COPYING.LIB NEWS README
%{_bindir}/osinfo-detect
%{_bindir}/osinfo-query
%{_bindir}/osinfo-install-script
%{_mandir}/man1/osinfo-detect.1.*
%{_mandir}/man1/osinfo-query.1.*
%{_mandir}/man1/osinfo-install-script.1.*

%files -n %{libname}
%{_libdir}/%{name}-%{api}.so.%{major}{,.*}

%files -n %{develname}
%{_libdir}/%{name}-%{api}.so
%dir %{_includedir}/%{name}-%{api}/
%dir %{_includedir}/%{name}-%{api}/osinfo/
%{_includedir}/%{name}-%{api}/osinfo/*.h
%{_libdir}/pkgconfig/%{name}-%{api}.pc
%{_datadir}/gir-1.0/Libosinfo-%{api}.gir
%{_datadir}/gtk-doc/html/Libosinfo

%files vala
%{_datadir}/vala/vapi/libosinfo-1.0.deps
%{_datadir}/vala/vapi/libosinfo-1.0.vapi

%files -n %{girname}
%{_libdir}/girepository-1.0/Libosinfo-%{girmajor}.typelib



%changelog
* Sun Jul 26 2020 daviddavid <daviddavid> 1.8.0-2.mga8
+ Revision: 1609040
- fix build with meson 0.55

* Sat May 30 2020 tv <tv> 1.8.0-1.mga8
+ Revision: 1589111
- 1.8.0

* Wed Feb 19 2020 umeabot <umeabot> 1.7.1-3.mga8
+ Revision: 1543077
- Mageia 8 Mass Rebuild

* Tue Jan 14 2020 tv <tv> 1.7.1-2.mga8
+ Revision: 1477863
- Fix OsinfoList ABI breakage

* Thu Dec 05 2019 tv <tv> 1.7.1-1.mga8
+ Revision: 1464452
- Update to 1.7.1 release

* Fri Nov 29 2019 tv <tv> 1.7.0-1.mga8
+ Revision: 1463774
- Update to 1.7.0 release

* Fri Nov 08 2019 tv <tv> 1.6.0-2.mga8
+ Revision: 1458811
- Improve ISO detection mechanism

* Tue Aug 06 2019 tv <tv> 1.6.0-1.mga8
+ Revision: 1427687
- new release
- drop obsolete BuildConflicts

* Wed Jul 10 2019 tv <tv> 1.5.0-2.mga8
+ Revision: 1419884
- CVE-2019-13313 libosinfo: osinfo-install-script option leaks password via
  command line argument (rhbz#1727767)

* Mon Jul 01 2019 tv <tv> 1.5.0-1.mga8
+ Revision: 1416627
- Update to 1.5.0 release
- Fix coverity issues

* Wed Apr 10 2019 tv <tv> 1.4.0-2.mga7
+ Revision: 1388190
- Fix usage of application ID
- Fix images' load
- Remove tests depending on osinfo-db

* Mon Mar 04 2019 tv <tv> 1.4.0-1.mga7
+ Revision: 1371453
- new release

* Thu Jan 31 2019 tv <tv> 1.3.0-1.mga7
+ Revision: 1362038
- new release

* Sat Oct 13 2018 tv <tv> 1.2.0-4.mga7
+ Revision: 1319973
- Do not force anchored patterns on libosinfo, leave it for osinfo-db

* Sun Sep 23 2018 umeabot <umeabot> 1.2.0-3.mga7
+ Revision: 1299074
- Mageia 7 Mass Rebuild
+ tv <tv>
- Require osinfo-db >= 20180920-1
- Force anchored patterns when matching regex

* Wed Jun 20 2018 tv <tv> 1.2.0-1.mga7
+ Revision: 1238312
- new release

* Mon May 07 2018 zezinho <zezinho> 1.1.0-6.mga7
+ Revision: 1227184
- conflicts with hwdata to fix bug mga#22999
+ kekepower <kekepower>
- Use new make macros

* Mon Mar 26 2018 tv <tv> 1.1.0-5.mga7
+ Revision: 1212692
+ rebuild (emptylog)

* Tue Mar 13 2018 tv <tv> 1.1.0-4.mga7
+ Revision: 1208910
- split vala subpkg

* Tue Sep 05 2017 tv <tv> 1.1.0-1.mga7
+ Revision: 1151295
- new release

* Wed Aug 02 2017 tv <tv> 1.0.0-1.mga7
+ Revision: 1133950
- new release (using split of osinfo-db)
- patch0: ignore checks in po/ subdir
- drop common subpkg

* Tue Jun 07 2016 tv <tv> 0.3.0-3.mga6
+ Revision: 1020516
- ensure we use the right devices by default for MGA VMs:
  o virtio, QXL & the like
  o but especially the USB tablet aka mouse integration, mostly for drakx
    (as it works out of the box with legacy mouse after install thx to agents)

* Fri Mar 25 2016 tv <tv> 0.3.0-2.mga6
+ Revision: 995467
- reenable testsuite after fixing

* Fri Mar 25 2016 tv <tv> 0.3.0-1.mga6
+ Revision: 995453
- new release
- remove no more existing option
- make it use pci.ids + usb.ids from ldetect-lst
- adjust file list
- testsuite fails
- add support for mga[45] too
- restrict matching

* Fri Mar 25 2016 tv <tv> 0.2.12-9.mga6
+ Revision: 995431
- mga support patch:
  o split netinstall
  o add variant IDs
  o add kernel/initrd pathes
  o make live be x86_64

* Fri Mar 25 2016 tv <tv> 0.2.12-8.mga6
+ Revision: 995426
- enhance mga support patch

* Fri Mar 25 2016 tv <tv> 0.2.12-7.mga6
+ Revision: 995350
- recognize regular install DVD instead of just boot.iso

* Thu Mar 24 2016 tv <tv> 0.2.12-6.mga6
+ Revision: 995224
- actually apply patch :-(

* Thu Mar 24 2016 tv <tv> 0.2.12-5.mga6
+ Revision: 995207
- patch 0: add support for generic Mageia

* Thu Feb 11 2016 umeabot <umeabot> 0.2.12-4.mga6
+ Revision: 955611
- Mageia 6 Mass Rebuild

* Mon Jun 29 2015 wally <wally> 0.2.12-3.mga6
+ Revision: 847871
- drop bogus requires

* Mon Jun 29 2015 wally <wally> 0.2.12-2.mga6
+ Revision: 847560
- add requires for gir pkg to devel pkg

* Mon Jun 22 2015 ovitters <ovitters> 0.2.12-1.mga6
+ Revision: 838838
- new version 0.2.12

* Fri Oct 24 2014 cjw <cjw> 0.2.11-5.mga5
+ Revision: 792896
- use upstream mageia os definition, fixes virt-manager VM creation wizard

* Wed Oct 15 2014 umeabot <umeabot> 0.2.11-4.mga5
+ Revision: 740629
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 wally <wally> 0.2.11-3.mga5
+ Revision: 724925
- rebuild with new rpm-mageia-setup to generate requires for .typelib files

* Tue Sep 16 2014 umeabot <umeabot> 0.2.11-2.mga5
+ Revision: 681691
- Mageia 5 Mass Rebuild
+ tv <tv>
- auto convert _exclude_files_from_autoreq

* Wed Aug 27 2014 pterjan <pterjan> 0.2.11-1.mga5
+ Revision: 668806
- 0.2.11 (needed by latest gnome-boxes)

* Sat May 17 2014 sander85 <sander85> 0.2.10-1.mga5
+ Revision: 623386
- New version: 0.2.10

* Wed Feb 05 2014 ovitters <ovitters> 0.2.9-1.mga5
+ Revision: 583809
- new version 0.2.9

* Sat Oct 19 2013 umeabot <umeabot> 0.2.7-2.mga4
+ Revision: 523836
- Mageia 4 Mass Rebuild

* Sat May 25 2013 blino <blino> 0.2.7-1.mga4
+ Revision: 427655
- package datamaps files
- package lang files
- 0.2.7

* Sat Jan 12 2013 umeabot <umeabot> 0.2.1-2.mga3
+ Revision: 357938
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Nov 08 2012 fwang <fwang> 0.2.1-1.mga3
+ Revision: 316302
- new version 0.2.1

* Tue Sep 11 2012 ovitters <ovitters> 0.2.0-1.mga3
+ Revision: 292442
- update file list
- br libxslt
- new version 0.2.0

* Sun Sep 02 2012 fwang <fwang> 0.1.2-3.mga3
+ Revision: 287254
+ rebuild (emptylog)

* Sun Sep 02 2012 fwang <fwang> 0.1.2-2.mga3
+ Revision: 287215
- add mageia distro

* Thu Aug 16 2012 fedya <fedya> 0.1.2-1.mga3
+ Revision: 281499
- version update 0.1.2

* Tue May 29 2012 ovitters <ovitters> 0.1.1-1.mga3
+ Revision: 249210
- update file list
- update buildrequires
- update buildrequires
- new version 0.1.1

* Wed Feb 08 2012 ovitters <ovitters> 0.1.0-1.mga2
+ Revision: 206368
- new version

* Mon Jan 16 2012 ovitters <ovitters> 0.0.5-1.mga2
+ Revision: 196942
- new version 0.0.5

* Sat Dec 17 2011 ovitters <ovitters> 0.0.3-1.mga2
+ Revision: 183049
- new version 0.0.3

* Thu Dec 01 2011 fwang <fwang> 0.0.2-2.mga2
+ Revision: 174689
- exclude req for demo files

* Wed Nov 30 2011 ovitters <ovitters> 0.0.2-1.mga2
+ Revision: 174375
- fix spec
- imported package libosinfo

